pub struct SettingsPanel {
pub open: bool,
pub page: SettingsPage,
pub selected: usize,
pub draft: Config,
pub dirty: bool,
pub status: Option<String>,
}Fields
open: boolpage: SettingsPageselected: usizeRow selection within the current page (for toggles/lists).
draft: ConfigWorking copy of config while the panel is open.
dirty: boolstatus: Option<String>Implementations
Sourceimpl SettingsPanel
impl SettingsPanel
pub fn new() -> Self
pub fn open_panel(&mut self)
pub fn close(&mut self)
pub fn visible(&self) -> bool
pub fn setting_rows(&self) -> Vec<SettingRow>
pub fn page_item_count(&self) -> usize
pub fn pet_rows(&self) -> Vec<SettingRow>
Sourcepub fn move_sel(&mut self, delta: isize)
pub fn move_sel(&mut self, delta: isize)
Skip non-selectable header rows when moving selection on Setting page.
pub fn next_page(&mut self)
pub fn prev_page(&mut self)
Sourcepub fn activate(&mut self) -> SettingsAction
pub fn activate(&mut self) -> SettingsAction
Activate / toggle the selected row. Returns optional UI action.
pub fn save(&mut self)
pub fn version_string() -> String
Sourceimpl SettingsPanel
impl SettingsPanel